---
name: Standard Request
about: Describes a basic request following the standard process.
title: 'Request: [[SUMMARY]]'
labels: enhancement
assignees: ''

---

Would you kindly add the following text to the README and implement the required code changes?

[[REQUEST]]

This feature has been marked for the next release. Thanks.
